@@ -13,6 +13,7 @@ from ..drawables.linegl import LineGL
 from ..drawables.pointgl import PointGL
 from ..drawables.tubegl import TubeGL
 from ..drawables.textgl import TextGL
+from ..drawables.gridgl import GridGL
 
 from ..glprograms.meshprogram import MeshProgram
 from ..glprograms.wireprogram import WireProgram
@@ -31,11 +32,11 @@ from ..glprograms.xsectionmeshprogram import XSectionMeshProgram
 from ..glprograms.xsectionblockprogram import XSectionBlockProgram
 
 from ..glprograms.textprogram import TextProgram
+from ..glprograms.gridprogram import GridProgram
 
 
 class GLDrawableCollection(GLCollection):
-    def __init__(self):
-        super().__init__()
+    def generate_associations(self):
         # Lines/Tubes/Points
         self.associate(LineProgram(), LineGL)
         self.associate(TubeProgram(), TubeGL)
@@ -58,3 +59,6 @@ class GLDrawableCollection(GLCollection):
 
         # Text
         self.associate(TextProgram(), TextGL)
+
+        # Axis
+        self.associate(GridProgram(), GridGL)
