@@ -12,6 +12,6 @@ from ..glprograms.axisprogram import AxisProgram
 
 
 class GLPostCollection(GLCollection):
-    def __init__(self):
-        super().__init__()
+    def generate_associations(self):
+        # Orientation Axis (the one in the corner)
         self.associate(AxisProgram(), AxisGL)
