@@ -10,12 +10,14 @@ import traceback
 from .drawables.gldrawable import GLDrawable
 from .drawables.axisgl import AxisGL
 from .drawables.backgroundgl import BackgroundGL
+
 from .drawables.meshgl import MeshGL
 from .drawables.blockgl import BlockGL
 from .drawables.pointgl import PointGL
 from .drawables.linegl import LineGL
 from .drawables.tubegl import TubeGL
 from .drawables.textgl import TextGL
+from .drawables.gridgl import GridGL
 
 
 class DrawableFactory:
@@ -61,6 +63,9 @@ class DrawableFactory:
     def text(self, *args, **kwargs) -> TextGL:
         return self.generate_drawable(TextGL, self.engine.text, *args, **kwargs)
 
+    def grid(self, *args, **kwargs) -> GridGL:
+        return self.generate_drawable(GridGL, self.engine.null, *args, **kwargs)
+
     """
     Drawables by path
     """
