@@ -31,10 +31,17 @@ class CharacterSlot:
 class TextGL(GLDrawable):
     def __init__(self, element, *args, **kwargs):
         super().__init__(element, *args, **kwargs)
-        self.fontfile = r'/usr/share/fonts/gnu-free/FreeMono.otf'
-        self.face = freetype.Face(self.fontfile)
+        self.fontfile = r'/usr/share/fonts/TTF/cour.ttf'
+
+        try:
+            self.face = freetype.Face(self.fontfile)
+        except freetype.ft_errors.FT_Exception:
+            self.fontfile = r'C:\Windows\Fonts\cour.ttf'
+            self.face = freetype.Face(self.fontfile)
+
         self.characters = {}
         self.text_vertices = []
+        self.vertices = np.empty(3)
 
         self.text = kwargs.get('text', ' ')
         self.scale = kwargs.get('scale', 0.1)
@@ -44,6 +51,14 @@ class TextGL(GLDrawable):
         # Set character size
         self.face.set_char_size(48 * 64)
 
+    def initialize(self) -> None:
+        if self.is_initialized:
+            return
+
+        self.initialize_textures()
+        super().initialize()
+
+    def initialize_textures(self) -> None:
         # Load first 128 characters of ASCII set
         self._setup_characters()
 
