@@ -9,14 +9,14 @@ from .shaderprogram import ShaderProgram
 
 
 class BackgroundProgram(ShaderProgram):
-    def __init__(self, viewer):
-        super().__init__(viewer)
+    def __init__(self):
+        super().__init__()
         self.base_name = 'Background'
 
     def initialize(self) -> None:
         super().initialize()
-        self.add_uniform_loc('top_color')
-        self.add_uniform_loc('bottom_color')
+        self.add_uniform_handler('top_color')
+        self.add_uniform_handler('bottom_color')
 
     def inner_draw(self, drawables: list) -> None:
         for drawable in drawables:
