@@ -6,6 +6,7 @@
 #  See LICENSE for more info.
 
 from .shaderprogram import ShaderProgram
+from qtpy.QtGui import QOpenGLShader
 
 
 class BlockProgram(ShaderProgram):
@@ -17,13 +18,11 @@ class BlockProgram(ShaderProgram):
         super().initialize()
         self.add_uniform_handler('block_size')
 
-    def setup_shaders(self) -> None:
-        # Placeholders to avoid early garbage collection
-        vs = self.enable_vertex_shader()
-        fs = self.enable_fragment_shader()
-        gs = self.enable_geometry_shader()
+    def generate_shaders(self) -> list:
+        shaders = super().generate_shaders()
+        shaders.append(self.generate_shader(QOpenGLShader.Geometry, self.geometry_path))
 
-        self.shader_program.link()
+        return shaders
 
     def inner_draw(self, drawables: list) -> None:
         for drawable in drawables:
